import React, { useEffect, useMemo, useState } from 'react'
import styles from './index.less'
import { Table, Tooltip } from 'antd'
import SearchGroup from './components/SearchGroup'
import TablePack from './components/TablePack'
import { GetAccountConfigInfo, GetAccountPageList, getStationListByUserID, GetTableJson } from '../../apis/process'
import { isJson, isObject } from '../../utils/index'

const getFileInfo = (formJson) => {
  let obj = {}
  let json = isJson(formJson) ? JSON.parse(formJson) : {}
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          obj[s] = child[s]
        }
      }
    }
  }
  console.log('obj', obj)
  return obj
}

const TableRender = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { accountName } = props
  const [loading, setLoading] = useState(false)
  const [config, setConfig] = useState({ webShowFieldGroup: '', formJson: '' })
  const [dataSource, setDataSource] = useState([])

  const columns = useMemo(() => {
    const { webShowFieldGroup, formJson } = config
    let showField = webShowFieldGroup ? webShowFieldGroup.split(',').filter(v => v) : []
    let json = getFileInfo(formJson)
    let array = []
    showField.forEach(v => {
      array.push({
        key: new Date().getTime(),
        title: json[v]?.title || v,
        dataIndex: v,
        width: 120,
        ellipsis: true,
        render: (value, r) => {
          let props = { ...json[v], value }
          return (
            <TablePack {...props} />
          )
        }
      })
    })
    return array
  }, [config])

  const getConfig = async () => {
    const { code, data } = await GetAccountConfigInfo(accountName)
    // if (code === 0) {
    //   setConfig(data)
    // }
    const res = await GetTableJson(accountName)
    if (code === 0 && res.code === 0) {
      setConfig({ ...data, formJson: res.data })
    }
  }

  const getDataSource = async (param) => {
    setLoading(true)
    let params = {
      userID: userID,
      accountName: '',
      direction: 'desc',
      timeField: '录入时间',
      pageIndex: 1,
      pageSize: 100,
      ...param,
    }
    const { code, data } = await GetAccountPageList(params)
    if (code === 0) {
      setDataSource(JSON.parse(data.jsonData))
    }
    setLoading(false)
  }

  const getData = () => {
    getConfig()
    getDataSource({ accountName })
  }

  useEffect(() => {
    getData()
  }, [])

  return (
    <div className={styles.tableRender}>
      <div className={styles.top}>
        {/* <SearchGroup /> */}
      </div>
      <div className={styles.bottom}>
        <Table
          size='small'
          bordered
          loading={loading}
          columns={columns}
          dataSource={dataSource}
          pagination={false}
          scroll={{ y: 'calc(100% - 50px)' }}
        />
      </div>
    </div>
  )

}

export default TableRender